@@ -2,21 +2,10 @@
 
 
 import logging
-
-try:
-    import pkg_resources
-    __version__ = pkg_resources.get_distribution('tldextract').version  # pylint: disable=no-member
-except ImportError:
-    __version__ = '(local)'
-except pkg_resources.DistributionNotFound:
-    __version__ = '(local)'
+import sys
 
 from .tldextract import TLDExtract
-
-try:
-    unicode
-except NameError:
-    unicode = str  # pylint: disable=invalid-name,redefined-builtin
+from ._version import version as __version__
 
 
 def main():
@@ -29,28 +18,29 @@ def main():
         prog='tldextract',
         description='Parse hostname from a url or fqdn')
 
-    parser.add_argument('--version', action='version', version='%(prog)s ' + __version__)  # pylint: disable=no-member
+    parser.add_argument('--version', action='version', version='%(prog)s ' + __version__)
     parser.add_argument('input', metavar='fqdn|url',
-                        type=unicode, nargs='*', help='fqdn or url')
+                        type=str, nargs='*', help='fqdn or url')
 
     parser.add_argument('-u', '--update', default=False, action='store_true',
                         help='force fetch the latest TLD definitions')
-    parser.add_argument('-c', '--cache_file',
-                        help='use an alternate TLD definition file')
+    parser.add_argument('-c', '--cache_dir',
+                        help='use an alternate TLD definition caching folder')
     parser.add_argument('-p', '--private_domains', default=False, action='store_true',
                         help='Include private domains')
 
     args = parser.parse_args()
     tld_extract = TLDExtract(include_psl_private_domains=args.private_domains)
 
-    if args.cache_file:
+    if args.cache_dir:
         tld_extract.cache_file = args.cache_file
 
     if args.update:
         tld_extract.update(True)
-    elif len(args.input) is 0:
+    elif not args.input:
         parser.print_usage()
-        exit(1)
+        sys.exit(1)
+        return
 
     for i in args.input:
         print(' '.join(tld_extract(i)))  # pylint: disable=superfluous-parens
